@@ -1,11 +1,11 @@
 import getpass
 import os
+from io import StringIO
 
 import paramiko
 from dagster import Field, StringSource, check, resource
 from dagster.utils import merge_dicts, mkdir_p
 from paramiko.config import SSH_PORT
-from six import StringIO
 from sshtunnel import SSHTunnelForwarder
 
 
@@ -20,7 +20,7 @@ def key_from_str(key_str):
     return result
 
 
-class SSHResource(object):
+class SSHResource:
     """
     Resource for ssh remote execution using Paramiko.
     ref: https://github.com/paramiko/paramiko
